# PixelFuse

Convert **any file to video** and video to file

## 💿 Installation

```bash
pip install pixelfuse
```

## Usage

```bash
python -m pixelfuse fileToVideo "test/example.text.txt"
```

And you get video

```bash
python -m pixelfuse videoToFile "test/example.video.avi"
```

And you get your file back
